﻿window.onload = function () {
    var app = new Vue({
        el: '#app',
        data: {
        }
    });
};

Vue.component('services_list', {
    data: function () {
        return {
            devices: [],
            selectedDevice: null,
            advancedModeEnabled: false,
            services: [],
            servicesURL: [],
            servicesInfo: []
        }
    },
    props: ['recurring'],

    template: '<div id="deviceList" >\
                    <div class="row no-select">\
                        <div v-for="(service, index) in servicesInfo" class="col-md-12">\
                            <div id="device" class="service bg-light">\
                                <div class="row">\
                                    <div @click="trigger({ index })" class="col-lg-1 col-md-1 col-sm-1 ellipsis"> \
                                        <span class="text-dark">SERVICE: </span>\
                                    </div> \
                                    <div @click="trigger({ index })" class="col-lg-2 col-md-2 col-sm-2 ellipsis"> \
                                        <span class="text-primary nowrap">#{{ service.id }} - {{ service.name }}</span>\
                                    </div> \
                                    <div @click="trigger({ index })" class="col-lg-3 col-md-2 col-sm-3 ellipsis"> \
                                        <a href="{{ service.url }}" >{{ service.url }}</a> \
                                    </div> \
                                    <div class="col-lg-3 col-md-5 col-sm-5"> \
                                    </div> \
                                </div>\
                            </div>\
                        </div>\
                    </div>\
                </div>',
    mounted: function () {
        var self = this;
        self.reload();        
    },
    computed: {
        advancedMode: function () {
            var self = this;
            return self.advancedModeEnabled
        },
        normalMode: function () {
            var self = this;
            return !self.advancedModeEnabled
        }
    },
    methods: {
        trigger(args) {            
            var self = this;
        },
        reload() {
            var self = this;                       

            $.getJSON("/services.json",
                function (data) {
                    for (var i = 0, len = data.length; i < len; i++) {
                        var source = data[i];
                        self.services.push(source);
                        var serviceURL = "/" + source + "/mpd" + source + ".xml";
                        self.servicesURL.push(serviceURL)
                        console.log(serviceURL);


                        var getUrl = window.location;
                        var baseUrl = getUrl.protocol + "//" + getUrl.host;
                        var url = baseUrl + serviceURL;

                        var serviceInfo = { id: source, name: "unknown", url: url };
                        self.servicesInfo.push(serviceInfo);

                        // load service data 
                        $.ajax({
                            type: "GET",
                            url: serviceURL,
                            dataType: "text",
                            success: function (xml) {
                                xml = xml.replace('xmlns="urn:mpeg:dash:schema:mpd:2011"', '');
                                var parser = new DOMParser();
                                var xmlDoc = parser.parseFromString(xml, "text/xml");
                                var results = xmlDoc.evaluate('//AdaptationSet', xmlDoc, null, XPathResult.ANY_TYPE, null);
                                while (node = results.iterateNext()) {
                                    console.log(node);
                                    var mimeType = node.getAttribute("mimeType");
                                    console.log(mimeType);
                                    var lang = node.getAttribute("lang");

                                    let children = node.childNodes;
                                    for (let i = 0; i < children.length; i++) {
                                        let child = children[i];
                                        if (child.nodeName == "Representation") {
                                            if (mimeType == "video/mp4") {
                                                var codec = child.getAttribute("codecs");
                                                var width = child.getAttribute("width");
                                                var height = child.getAttribute("height");
                                                var scanType = child.getAttribute("scanType");
                                                var frameRate = child.getAttribute("frameRate");
                                                var bandwidth = child.getAttribute("bandwidth");
                                                console.log("VIDEO: " + codec + " " + width + "x" + height + " " + frameRate + " " + scanType + " " + bandwidth);

                                            } else if (mimeType == "audio/mp4") {
                                                var codec = child.getAttribute("codecs");
                                                var audioSamplingRate = child.getAttribute("audioSamplingRate");
                                                var bandwidth = child.getAttribute("bandwidth");
                                                console.log("AUDIO: " + codec + " " + audioSamplingRate + " " + bandwidth + " " + lang);

                                            } else {
                                                var codec = child.getAttribute("codecs");                                                
                                                var bandwidth = child.getAttribute("bandwidth");
                                                console.log("APPLICATION: " + codec + " " + audioSamplingRate + " " + bandwidth + " " + lang);

                                            }                                                                                    
                                        }
                                    }                                    
                                }
                            }
                        });
                    }                    
                }
            );
            

            var url = 'services/service?method=setting.devices&format=json';
            $.getJSON(url, function (data) {
                if (data.hasOwnProperty('stat') && data.stat == "Failed") {
                    self.devices = [];
                } else {
                    for (var i = 0, len = data.length; i < len; i++) {
                        var source = data[i];
                        if (source.channelCount > 0) {
                            source.channelSummary = " " + source.channelCount + " channels";
                        }
                        source.presentSummary = "";
                        if (source.enabled == false) {
                            source.presentSummary = " (disabled)";
                        }
                        if (source.present == false) {
                            source.presentSummary += " (unavailable)";
                        }
                        if (source.enabled) {
                            source.toggleAction = "Disable";
                        } else {
                            source.toggleAction = "Enable";
                        }
                    }
                    self.devices = data;
                }
            });
        }, 
        forceRefresh() {
            var self = this;
            var url = 'services/service?method=setting.devices&refresh=true&format=json';
            $.getJSON(url, function (data) {
                for (var i = 0, len = data.length; i < len; i++) {
                    var source = data[i];
                    if (source.channelCount > 0) {
                        source.channelSummary = " " + source.channelCount + " channels";
                    }
                    source.presentSummary = "";
                    if (source.present == false) {
                        source.presentSummary = " (unavailable)";
                    }                    
                }
                self.devices = data;
            });
        },
        showAdvancedMode() {
            var self = this;
            self.advancedModeEnabled = true;            
        },
        showNormalMode() {
            var self = this;            
            self.advancedModeEnabled = false;            
        },
        toggleDevice(args) {
            var self = this;
            var device = args.device;
            var url = 'services/service?method=setting.device.enable&source_id=' + device.id;
            if (device.toggleAction === "Disable") {
                url = 'services/service?method=setting.device.disable&source_id=' + device.id;
            }            
            $.getJSON(url, function (data) {
                self.reload();
            });
        },
        deleteDevice(args) {
            var self = this;  
            var device = args.device;
            var url = 'services/service?method=setting.device.delete&source_id=' + device.id;
            $.getJSON(url, function (data) {                
                self.reload();
            });            
        },
        exportDevice(args) {
            var self = this;
            var device = args.device;
            var url = 'services/service?method=setting.device.export&source_id=' + device.id;
            $.getJSON(url, function (data) {
                self.reload();
            });
        }
    }
});
